@@ -13,7 +13,6 @@ import astropy.coordinates as apc
 from astropy.time import Time
 from dkist_processing_pac import TelescopeModel, CUModel, generic
 from dkist_processing_pac.tag import tag
-from dkist_processing_pac.M12 import ContinuumPolarization
 from dkist_processing_pac.data import S122
 from astropy.utils.exceptions import ErfaWarning
 from dkist_fits_specifications import spec122
@@ -747,67 +746,6 @@ def print_truth(truth_file='truth.pkl'):
             except ValueError:
                 print('{:10}'.format(truth[k]))
 
-def make_M12_map(outdir, simdir='/home/ade/PycharmProjects/ViSP_pipeline/sim_data',
-                 low_lim=15, high_lim=75, cont_low=-20, cont_high=None, datanoise=0):
-
-    TM = TelescopeModel.TelescopeModel(0,0,0)
-    np.random.seed(13)
-    TM.x12 = np.random.random() * 0.35 + 0.9
-    TM.t12 = (np.random.random() * 60 + 150.) * np.pi / 180
-
-    for i in range(1000):
-        print(i)
-        hdus = pyfits.open('{:}/stokes/image.{:04}.fits'.format(simdir,i))
-        stokes = np.dstack([h.data for h in hdus[1:]])
-
-        data = np.sum(TM.M12 * stokes[:, :, None, :], axis=3)
-
-        if datanoise:
-            data += np.random.randn(*data.shape) * datanoise * np.mean(data)
-
-        hdulist = pyfits.HDUList([pyfits.PrimaryHDU()])
-        for j, s in enumerate(['I','Q','U','V']):
-            hdulist.append(pyfits.ImageHDU(data[:, low_lim:high_lim, j]))
-            hdulist[-1].header['VISP_STK'] = s
-            hdulist[-1].header[S122['Wavelength']] = 588
-            hdulist[-1].header['DATE-OBS'] = Time(57560, format='mjd').fits
-
-        hdulist.writeto('{}/M12.{:04n}.FITS'.format(outdir, i), overwrite=True)
-
-        I = data[:, cont_low:cont_high, 0]
-        Q = data[:, cont_low:cont_high, 1]
-        U = data[:, cont_low:cont_high, 2]
-
-        i2q = np.nanmedian(Q / I)
-        i2u = np.nanmedian(U / I)
-
-        ContinuumPolarization.update_xtalk_database(i2q, i2u, 'gen_fake_data',
-                                                    Time.now().mjd, 666)
-        hdus.close()
-        del hdus
-        del stokes
-
-    big_list = []
-    for i in range(1000):
-        print(i)
-        hdus = pyfits.open('{}/M12.{:04}.FITS'.format(outdir,i))
-        big_list.append(np.dstack([h.data for h in hdus[1:]]))
-        hdus.close()
-
-    big_map = np.stack(big_list, 1)
-    del big_list
-    print(big_map.shape)
-    print(TM.x12, TM.t12)
-
-    hdulist = pyfits.HDUList([pyfits.PrimaryHDU()])
-    for i in range(4):
-        hdulist.append(pyfits.ImageHDU(big_map[:, :, :, i]))
-
-    hdulist[0].header[S122['Wavelength']] = 588
-    hdulist[0].header['DATE-OBS'] = Time(57560, format='mjd').fits
-    hdulist.writeto(outdir + '/full_maps.FITS', overwrite=True)
-
-    return
 
  #  re-work of Arthur's function by DMH
 def compute_telgeom(time_hst):
